@@ -14,14 +14,14 @@ from .utils import exceptions
 
 class Bot:
     """
-    Nertivia Gateway Client  
-    This is the client that handles all of the events from the Nertivia Gateway.  
-    And it also handles all of the commands that are sent to the bot.  
+Nertivia Gateway Client  
+This is the client that handles all of the events from the Nertivia Gateway.  
+And it also handles all of the commands that are sent to the bot.  
 
-    Attributes:
-        command_prefix (str): The prefix that is used to identify commands.
-        self_bot (bool): Whether or not the bot is a self bot.
-        debug (bool): Whether or not to send socket debug messages.
+Attributes:
+- command_prefix (str): The prefix that is used to identify commands.
+- self_bot (bool): Whether or not the bot is a self bot.
+- debug (bool): Whether or not to send socket debug messages.
     """
 
     def __init__(self, command_prefix, self_bot=False, debug=False) -> None:
@@ -45,13 +45,13 @@ class Bot:
 
     def run(self, token) -> None:
         """
-        Run the client  
+Run the client  
 
-        Args:
-            token (str): The token that is used to authenticate the bot.
+Args:
+- token (str): The token that is used to authenticate the bot.
 
-        Raises:
-            InvalidToken: If the token is invalid.
+Raises:
+- InvalidToken: If the token is invalid.
         """
 
         extra.Extra.setauthtoken(token)
@@ -129,20 +129,20 @@ class Bot:
 
     def register_command(self, **kwargs) -> None:
         """
-        Register a command.  
+Register a command.  
 
-        Args:
-            name (str): The name of the command.
-            description (str): The description of the command.
-            usage (str): The usage of the command.
-            aliases (list): A list of aliases for the command.
-            callback (func): The callback function for the command. / What the command does.
+Args:
+- name (str): The name of the command.
+- description (str): The description of the command.
+- usage (str): The usage of the command.
+- aliases (list): A list of aliases for the command.
+- callback (func): The callback function for the command. / What the command does.
 
-        Aliases:
-            add_command(**kwargs)
+Aliases:
+- add_command(**kwargs)
 
-        Raises:
-            CommandAlreadyExists: If the command already exists.
+Raises:
+- CommandAlreadyExists: If the command already exists.
         """
 
         description = kwargs["description"] if "description" in kwargs else ""
@@ -163,17 +163,17 @@ class Bot:
 
     def load_commands(self, **kwargs):
         """
-        Load commands from a separate file.
+Load commands from a separate file.
 
-        Args:
-            lib_path (str): The path to the file. (example: commands.general)
-            commands_class (str): The name of the class in the file. (example: Commands)
+Args:
+- lib_path (str): The path to the file. (example: commands.general)
+- commands_class (str): The name of the class in the file. (example: Commands)
 
-        Aliases:
-            add_commands(lib_path, commands_class)
+Aliases:
+- add_commands(lib_path, commands_class)
 
-        Raises:
-            AttributeError: If the class is not found.
+Raises:
+- AttributeError: If the class is not found.
         """
     
         if "lib_path" in kwargs:  lib_path = kwargs["lib_path"]
